function [foil,amr,pos,hull] = geomdef(sail,wind,B,hull,pos,foil,Vel)

% This function rotates and translats the geometry of the vessel. In
% addition it also determines the moment arms for torque calculation.

n = foil.n;
m = foil.n;
k = sail.k;
dt = sail.dt;
hullchar = hull.char;
beta = max(wind.beta);

ffpos = pos.foil.cord; spos = pos.sail.cord; hpos = pos.hull.cord;
fpos = pos.ff; criteria = pos.crit';


B0 = transmatrix(0,0,0);

origin = [0; 0; hull.char(5)];
% Rotating geometry and translating it.
if k == 1

newcrit = rotgeom(B,origin,criteria,[0 0 0],dt);
newfpos = rotgeom(B,origin,fpos,[0 0 0],dt);
newffpos = rotgeom(B,origin,ffpos,[0 0 0],dt);
newspos = rotgeom(B,origin,spos,[0 0 0],dt);
newhpos = rotgeom(B,origin,hpos,[0 0 0],dt);
charts = rotgeom(B,origin,spos,[0 0 0],dt);
charth = rotgeom(B,origin,hpos,[0 0 0],dt);
CG = rotgeom(B,origin,[0 0 hull.char(5)],[0 0 0],dt);

    pos.bod.foil = newfpos;
    pos.bod.foil2 = newffpos;
    pos.bod.sail = newspos;
    pos.bod.hull = newhpos;
    pos.bod.crit = newcrit;

else
    
     vel = Vel';
    
    bodcrit = pos.bod.crit';
    bodfpos = pos.bod.foil';
    bodffpos = pos.bod.foil2';
    bodspos = pos.bod.sail';
    bodhpos = pos.bod.hull';
    bodCG = pos.CG;
    
    bodcrit = rotgeom(B0,pos.CG,bodcrit,vel,dt);
    bodfpos = rotgeom(B0,pos.CG,bodfpos,vel,dt);
    bodffpos = rotgeom(B0,pos.CG,bodffpos,vel,dt);
    bodspos = rotgeom(B0,pos.CG,bodspos,vel,dt);
    bodhpos = rotgeom(B0,pos.CG,bodhpos,vel,dt);
    bodCG = rotgeom(B0,pos.CG,bodCG',vel,dt);
    
    pos.bod.foil = bodfpos;
    pos.bod.foil2 = bodffpos;
    pos.bod.sail = bodspos;
    pos.bod.hull = bodhpos;
    pos.bod.crit = bodcrit; 
    pos.bod.CG = bodCG;
   
    newfpos = rotgeom(B,pos.CG,bodfpos',[0 0 0],dt);
    newspos = rotgeom(B,pos.CG,bodspos',[0 0 0],dt);
    newhpos = rotgeom(B,pos.CG,bodhpos',[0 0 0],dt);
    newffpos = rotgeom(B,pos.CG,bodffpos',[0 0 0],dt);
    newcrit = rotgeom(B,pos.CG,bodcrit',[0 0 0],dt);
    
    charts = rotgeom(B,pos.CG,pos.chart.s',vel,dt);
    charth = rotgeom(B,pos.CG,pos.chart.h',vel,dt);
    CG = rotgeom(B0,origin,pos.CG',vel,dt);
    
end
pos.crit = newcrit;
fpos = newffpos;
newhpos = newhpos';
newspos = newspos';

% Finding the submerged section of the hydrofoils
P0 = (newfpos(:,2))';
P1 = (newfpos(:,1))';

I = plane_line_intersect(P0,P1);
    
newfpos(:,1) = I';

P0 = (newfpos(:,3))';
P1 = (newfpos(:,4))';

I = plane_line_intersect(P0,P1);

newfpos(:,3) = I';

P0 = (newfpos(:,7))';
P1 = (newfpos(:,8))';

I = plane_line_intersect(P0,P1);

newfpos(:,7) = I';
% Determining submerged span lengths
span1 = sqrt(((newfpos(2,2)-newfpos(2,1))^2)+((newfpos(3,2)-newfpos(3,1))^2)+((newfpos(1,2)-newfpos(1,1))^2));
span2 = sqrt(((newfpos(2,4)-newfpos(2,3))^2)+((newfpos(3,4)-newfpos(3,3))^2)+((newfpos(1,4)-newfpos(1,3))^2));
span3 = sqrt(((newfpos(2,6)-newfpos(2,5))^2)+((newfpos(3,6)-newfpos(3,5))^2)+((newfpos(1,6)-newfpos(1,5))^2));
span4 = sqrt(((newfpos(2,8)-newfpos(2,7))^2)+((newfpos(3,8)-newfpos(3,7))^2)+((newfpos(1,8)-newfpos(1,7))^2));

foil.span = [span1 span2 span3 span4];
% Determining the centre of the hydrofoils
arm1 = ((newfpos(:,1)+newfpos(:,2))/2)-CG;
arm2 = ((newfpos(:,3)+newfpos(:,4))/2)-CG;
arm3 = ((newfpos(:,5)+newfpos(:,6))/2)-CG;
arm4 = ((newfpos(:,8)+newfpos(:,7))/2)-CG;

amr.f = [arm1 arm2 arm3 arm4];
% Determining the maximum moment arm obtainable from the hydrofoils. Some
% vector manipulation is performed.
fpos2 = fpos';
px = reshape(fpos2(:,1),10,[]);
py = reshape(fpos2(:,2),10,[]);
pz = reshape(fpos2(:,3),10,[]);

maxmomentarm = [mean(px(:,1)) mean(px(:,2)) mean(px(:,3)) mean(px(:,4));...
                mean(py(:,1)) mean(py(:,2)) mean(py(:,3)) mean(py(:,4));...
                mean(pz(:,1)) mean(pz(:,2)) mean(pz(:,3)) mean(pz(:,4))];
% Determining moment arm of sail. Centroid of sail, not perfectly accurate
% but sufficient.
x = linspace(min(sail.chord),max(sail.chord),n);
z = linspace(0,sail.height,m)+hull.char(5);

XCE = sum(x)/length(x);
ZCE = (sum(z)/length(z))/2;

spos(:,2) = ones(n,1)*XCE*abs(sind(beta));

amr.sail = [XCE/4; XCE*abs(sind(beta)); ZCE];

L = hullchar(1);
B = hullchar(2);
D = hullchar(4);
Cm = hullchar(7);
Cb = hullchar(8);
Cp = hullchar(9);

hull.area = 2*L*D*Cp*Cm*Cb*B*0.6;

amr.hull = [0; 0; 0];

pos.CG = CG;
pos.ff = newfpos;
pos.chart.s = charts;
pos.chart.h = charth;
pos.sail.cord = newspos;
pos.hull.cord = newhpos;
pos.foil.cord = fpos';
hull.mass = sum(pos.hull.mass)+sum(pos.sail.mass)+sum(pos.foil.mass)+hull.crew;

% Determining the moment arms for the different hydrofoils.
if k == 1
   maxmomentarm(3,:) = -maxmomentarm(3,:)-1;
   pos.momentarm.f = maxmomentarm;
   pos.momentarm.sail = amr.sail;
   pos.momentarm.hull = amr.hull;
end

end