function aero = liftsail(sail,wind,dt,k,aero,pos,simstart)
% This function determines the lift and drag produced by a sail.
n = sail.n;
m = sail.m;
Vel = [wind.Va*cosd(11); wind.Va*sind(11); 0];
% De-powering the sail if a certain roll angle has been reached.
if sail.p > 1.5
    Vel = [wind.Va*cosd(7); wind.Va*sind(7); 0];
end
Vel = -Vel;
if k == 1
    
    res.k = 1;
    domain.CG = pos.CG;
    domain.rot = aero.rot;
    domain.vel = Vel;
    domain.dt = dt;
    domain.k = k;
    domain =  geomsail(sail,domain);
    domain.rho = 1.25;
    domain.dt = dt;
    domain.mm = m; domain.nn = n;
    
    domain.test.x2 = domain.test.x;
    domain.test.y2 = domain.test.y;
    domain.test.z2 = domain.test.z;
    
    domain.ang.phi = 90;
    domain.ang.the = 0;
    
    [dd,ff] = size(domain.test.x2);
    res.wake = ones(dd-1,ff-1);
    
    [res] = UVLM(Vel,domain,res);
    res.wake = res.circ(n,:);
    
    domain.chart.x = [domain.test.x(1,1) domain.test.x(1,m)];
    domain.chart.y = [domain.test.y(1,1) domain.test.z(1,m)];
    domain.chart.z = [domain.test.y(1,1) domain.test.z(1,m)];
    
   
else
    
    domain = aero.domain;
    domain.rot = aero.rot;
    domain.CG = pos.CG;
    domain.vel = Vel;
    domain.dt = dt;
    domain.k = k;
    domain = geomsail(sail,domain);
    
    res = aero.res;
    res.k = k;
    domain = diplacefast(domain,Vel);
    [res] = UVLM(Vel,domain,res);
    domain.test.x2 = [domain.test.x(1,:); domain.test.x2];
    domain.test.y2 = [domain.test.y(1,:); domain.test.y2];
    domain.test.z2 = [domain.test.z(1,:); domain.test.z2];
    res.wake = [res.circ(n,:); res.wake];
    
end

cutoff = simstart;
if k > cutoff
    
    res.wake(cutoff-1:end,:) = [];
    domain.test.x2(cutoff:end,:) = [];
    domain.test.y2(cutoff:end,:) = [];
    domain.test.z2(cutoff:end,:) = [];
    
end

aero.domain = domain;
aero.res = res;
end
