function [wind,sail,hull,pos,foil] = simparam(n,m)

%-----Vessel Parameters-------%

hull.char = [6;... % LOA
            0.5;... % Beam
            3;... % Gap between hulls, 0 if monohull
            1;... % Hull Depth 
            1;... % Assumed initial gap between hull and water surface
            1;... % Draft
            0.6;... % Midships Coefficient
            0.5;... % Block Coefficient
            0.5]; % Prism Coefficient

hull.weight = 250; % weight of the vessel
% Weight of crew, only 2 crew members simulated, assumed equal weight of
% crew members, below is total weight.
hull.crew = 160;

%-----Sail Parameters---------%

sail.chord = [0.2 0.75]; % Sail chord, requires two values
sail.height = 4.5; % Sail height;
sail.NACAS = '0012'; % Sail NACA profile
sail.rho = 1; % Air Density
sail.densit = 100; % Material density of the sail
sail.n = n; % Number of chordwise elements
sail.m = m; % Number of spanwise elements

%-----Foil Parameters--------%

foil.chord = [0.4 0.4 0.4 0.4];     % Chord lengths 
foil.angle = [60 -60 90 0];    % Angle of of foils, 0 if not used.
foil.angle2 = [0 180 0 0];     % Had to rotate port side foils by 180
foil.fore = 0.6;               % Position relativ COG
foil.aft = -hull.char(1)/2;    % Position relativ COGx
foil.spans = [4 4 1 2];        % Total Span length of different foils
foil.NACA = {'2412','2412','0012','0012'}; % NACA profiles
foil.rho = 1025;    % Density of water
foil.densit = 1000; % Material density of the foil, assumed carbon fibre
foil.n = n; %  Number of elements chordwise
foil.m = m; % Number of elements spanwise 
foil.extension = 4.5; % fore foil extension from the hull in y direction.

%-----Generating Foil coordinates-----%

pos = vesselgeom(hull,foil,sail);

%-----Wind Condition-------------------%
% Initialising values due to programming.
wind.Vt = -7; % Truw Wind Speed
wind.Va = 0;  % Apparent Wind Speed
wind.beta = 0; % Apparent Wind Angle

end