function [pos] = vesselgeom(hull,foil,sail)
n = foil.n;
m = foil.m;
hullchar = hull.char;

fangle = foil.angle(1);
foilfor = foil.fore;
foilaft = foil.aft;
spans = foil.spans;

% Determining vessel end points

a = fangle;
x1 = foilfor;
x2 = foilaft;

foilx = [x1 x1 x1 x1 x2 x2 x2 x2]';
beam = hullchar(2)*0.5;
beamgap = hullchar(3)*0.5;
depth = hullchar(4);
airgap = hullchar(5);
draft = hullchar(6);
extension = foil.extension;

y1 = extension;
z1 = 0;
y2 = y1-(spans(1)*cosd(90-a));
z2 = z1-(spans(1)*sind(90-a));

y3 = -y1;
z3 = z1;

y4 = -y2;
z4 = z2;

y5 = spans(3)/2;
z5 = -spans(4);

y6 = -y5;
z6 = z5;

y7 = 0;
z7 = 0;

y8 = 0;
z8 = z5;

foily = [y1 y2 y3 y4 y5 y6 y7 y8]';
foilz = airgap+[z1 z2 z3 z4 z5 z6 z7 z8]';


fpos = [foilx foily foilz]';
% Didtribution foil points
for k = 1:length(foil.spans)
    if k == 1
        x = linspace(fpos(1,k),fpos(1,k+1),n)';
        y = linspace(fpos(2,k),fpos(2,k+1),n)';
        z = linspace(fpos(3,k),fpos(3,k+1),n)';
    elseif k == 2
        x = [x; linspace(fpos(1,k+1),fpos(1,k+2),n)'];
        y = [y; linspace(fpos(2,k+1),fpos(2,k+2),n)'];
        z = [z; linspace(fpos(3,k+1),fpos(3,k+2),n)'];
    elseif k == 3
        x = [x; linspace(fpos(1,k+2),fpos(1,k+3),n)'];
        y = [y; linspace(fpos(2,k+2),fpos(2,k+3),n)'];
        z = [z; linspace(fpos(3,k+2),fpos(3,k+3),n)'];
    elseif k == 4
        x = [x; linspace(fpos(1,k+3),fpos(1,k+4),n)'];
        y = [y; linspace(fpos(2,k+3),fpos(2,k+4),n)'];
        z = [z; linspace(fpos(3,k+3),fpos(3,k+4),n)'];
    end
    
end

for k = 1:length(foil.spans)
    
    [~,~,~,XP,ZP] = foilpoints(cell2mat(foil.NACA(k)),foil.n);
    XP = XP*foil.chord(k);
    ZP = ZP*foil.chord(k);
    Volume = foil.spans(k)*polyarea(XP,ZP);
    mass = Volume*0.3*foil.densit;
    if k == 1
        md = ones(n,1)*(mass/n);
    else
        md = [md; ones(n,1)*(mass/n)];
    end
    
end

pos.ff = [foilx foily foilz];
pos.foil.cord = [x y z];
pos.foil.mass = md;
% Distribution hull and sail points
[~,~,~,XP,ZP] = foilpoints(sail.NACAS,sail.n);
Volume = sail.height*polyarea(XP,ZP);
mass = Volume*sail.densit*0.3;
sailmass = ones(n,1)*mass/n;

sailx = (linspace(-max(sail.chord)/2,-min(sail.chord)/2,n));
saily = linspace(0,0,n);
sailz = linspace(hull.char(5),sail.height+hull.char(5),n);

pos.sail.cord = [sailx; saily; sailz]';
pos.sail.mass = sailmass;

hullx = linspace(-hull.char(1)/2,hullchar(1)/2,n);
hully = zeros(1,n);
hullz = ones(n,1)*hull.char(5);
[dd,ff] = size(hullx);
hullmass = ones(ff,1)*hull.weight/(ff);
pos.hull.cord = [hullx; hully; hullz']';
pos.hull.mass = hullmass;
pos.crit = fpos;


pos.body.sail = pos.sail.cord;
pos.space.sail = pos.sail.cord;

pos.body.hull = pos.hull.cord;
pos.space.hull = pos.hull.cord;

pos.body.foil = pos.foil.cord;
pos.space.foil = pos.foil.cord;
end