function [domain,sav] = wakerollup(domain,sav)
% This function calculates the induced velocity at each point on the wake
% of a foil using biot-savart law. It requires a mesh field of equal size
% in (x,y,z) and a foil with (x,y,z) coordinates.

x = domain.x;
y = domain.y;
z = domain.z;
[a,b] = size(x);

for k = 1:a
    
    for l = 1:b
   % Point in the wake to be evaluated
    CP = [x(k,l) y(k,l) z(k,l)];
    % total induced velocity from the foil on the point in the wake
    vel = biotsavart(CP,domain,sav);
   % total induced velocity from the wake
    vel2 = biotsavartwake(CP,domain,sav);
    % Combined induced velocity
    yushx(k,l) = vel2(1)+sum(vel(:,1));
    yushy(k,l) = vel2(2)+sum(vel(:,2));
    yushz(k,l) = vel2(3)+sum(vel(:,3));

    end
    
end

domain.vel.x = yushx;
domain.vel.y = yushy;
domain.vel.z = yushz;

end